@@ -28,7 +28,10 @@ DelayStartTime_default=10 #Default recording start delay
 Yscale_Sleep_Pattern_default=40 #Y stretching of blue sleep pattern
 Yoffset_Sleep_Pattern_default= 0  #Y offset of blue sleep pattern
 
-configFileVersion=3 #increase if parameters have changed
+Light_Sleep_Level_default=70
+Deep_Sleep_Level_default=35
+
+configFileVersion=4 #increase if parameters have changed
 
 
 
@@ -55,10 +58,8 @@ Ysize=121 #default value Y scale in px
 
 
 
-
-
-Yscale_Movement=0 #Y stretching of yellow movement bars
 DelayStartTime=0
+Yscale_Movement=0 #Y stretching of yellow movement bars
 Yscale_Sleep_Pattern=0  #Y stretching of blue sleep pattern
 Yoffset_Sleep_Pattern= 0 #Y offset of blue sleep pattern
 
@@ -68,7 +69,6 @@ Xscale=1 #default value X scale in arraXscale index
 
 derivation_offset=2
 
-#Yscale_Movement_sleep=1
 
 Value_index=0
 Values_total=0
@@ -80,11 +80,8 @@ Trigger=14 #Trigger level for movement
 maxTrigger=120
 minTrigger = 1
 
-
-Light_Sleep_Level=70
-
-Deep_Sleep_Level=35
-
+Light_Sleep_Level=0
+Deep_Sleep_Level=0
 
 demo=0
 debug=False
@@ -97,9 +94,10 @@ LastRecord=""
 #ChangesInGraph=False
 run=False
 QuickMode=False
-version="0"
-build="0"
+version=0
+build=0
 
+LastWindow=""
 
 user=""
 app_path="./"
@@ -155,12 +153,9 @@ arrRecordFilesIndex=0
 RecordFileSelectedDate=""
 
 
-#Colors
+#Graph colors
 MovementBarColor="#DFAD09" #"Yellow"
-#AlarmColor="Red"
-#AlarmTimeWindowColor="Orange"
 GraphBackground="#000000"
-#GraphBackground="#101010"
 GraphBackground2="#2B2B2B"
 
 #Colors for time bars
