@@ -46,7 +46,8 @@ def error():
 def ErrorReportDialog(trace,txt_email=None):
     print "-----------------------------------------------------------------------------\n"
 #    item, ok = QInputDialog.getItem(None, 'Select voice type', "", "aabcde", 0, False)
-    print "## An error occurred!"
+    print "## Oops! An error occurred!"
+    print "Below is a print out of the record data as well as the configuration:"
     PrintRecordData(False)
     PrintConfig()
     print trace
